# pyfrogsay

A talking frog! Inspired by [pycowsay](https://pypi.org/project/pycowsay/)

## Run
Use pipx to run without permanently installing:

```bash
pipx run pyfrogsay opp opp
```

## Run with uvx
Use uvx to run without permanently installing:

```bash
uvx pyfrogsay opp opp
```

Example output:
```
  ----------
< opp opp >
  ----------
   \
   @..@
  (----)
 ( >__< )
 ^^    ^^
```